###############################################################################
#####                           Polish
###############################################################################
##### This file contains the Polish labels for the program
###############################################################################
##### Copyright 1999-2002 Andrs Garca Garca. You may redistribute this file
##### under the terms of the GPL license. 
##### Wersja polska: "ooshy"  <ooshy@poczta.onet.pl>
#####                Marek Dankowski <marek-sh@profit.pl>
###############################################################################

# Here come the menu labels

Menus

file            "&Plik"
enterUrl        "&Wpisz URL"
siteMap         "&Mapuj strony..."
resumeSite      "W&znw"
stop            "&Zatrzymaj"
stopPage        "Po tym dokumencie"
stopFile        "Po tym pliku"
stopNow         "Teraz"
pause           "&Pauza"
exit            "Wy&jcie"

options         "&Opcje"
all             "Wszystkie"
uplinks         "&Po linkach"
linksFollow     "Za linkami"
linksIgnore     "Ignoruj"
levels          "&Poziomy"
noLimit         "Bez limitu"
fileFilter      "&Filtruj pliki"
onlyHtml        "Tylko HTML"
chooseFilter    "Wybierz filtr..."
images          "Obrazki"
allImages       "Wszystko"
onlyThumb       "Tylko thumbnails"
noThumb         "Bez thumbnails"
external        "E&xternal links"
resume          "&Wznw"
update          "&Odwierz"
cgi             "&CGI"
useProxy        "&Uyj proxy"


checkSize       "Sprawd wielko"
encodings       "Kodowanie"

tools           "&Narzdzia"
purgeFiles      "&Cze plikw..."
restoreOrig     "&Przywr oryginalne..."
updateFiles     "Aktualizuj pliki..."
configureProxy  "&Konfiguracja proxy..."
languages       "&Jzyki"
getLog          "Historia cigania"
resource        "&rdo"

help            "Po&moc"
manual          "&Instrukcja"
changes         "&Zmiany"
license         "&Licencja"
about           "&O programie"

# Labels for the context menus

cut             "Wytnij"
copy            "Kopiuj"
paste           "Wklej"
clear           "Wyczy"
selectAll       "Wybierz wszystko"
delete          "Kasuj"
download        "cigaj"
queue           "Ustaw w kolejce"
localDir        "Bierzcy katalog"
notErase        "Nie czy"

# NOT TRANSLATED
top             "Top"
up              "Do gry"
down            "W d"
bottom          "Bottom"

# Labels for the encoding menus

europa          "Europa"
africa          "Afryka"
asia            "Azja"

ascii           "Ascii"
unicode         "Unicode"
westEuropa      "Zachodnioeuropejski"
celtic          "Celtycki"
greek           "Grecki"
iceland         "Islandzki"
baltic          "Batycki"
centerEuropa    "rodkowoeuropejski"
croatian        "Chorwacki"
cyrillic        "Cyrylica"
simpleChin      "Chiski uproszczony"
tradChin        "Chiski tradycyjny"
japan           "Japoski"
korean          "Koreaski"
turkish         "Turecki"
hebrew          "Hebrajski"
arabic          "Arabski"

End

# The button labels

Buttons

ok              "OK"
cancel          "Anuluj"
start           "Start"
options         "Opcje"
select          "Wybierz"
pause           "Pauza"
resume          "Wznw"
clear           "Wyczy"
skip            "Pomi"
chooseFilter    "Wybierz filtr"
help            "Pomoc"
# NOT TRANSLATED
load            "Load"
save            "Save"

back            "< Powrt"
next            "Nastpny >"
finish          "Koniec"

End

# The Windows titles

Titles

choose          "Wybierz Plik"
enterUrl        "Wpisz URL"
about           "O programie"
manual          "Instrukcja"
license         "Licencja"
directory       "Wybierz katalog"
newDir          "Nowy katalog"
purge 	        "Cz Pliku"
proxy 	        "Konfiguracja proxy"
download        "Pobierz plik"

process         "Pobieranie pliku"
connect         "Poczenie"
initError       "Pocztkowy bd"
error           "Bd"
preError        "Bd przetwarzania"
theEnd          "Koniec"
noLinks         "Brak linkw"
unknown         "Nieznany folder"
exclude         "Wyklucz pliki"
# errorLog        "Plik bdw"
paused          "Stop"
confirm         "Potwierd"
resumeSite      "Wznw"
up              "Do gry"
newDir          "Nowy katalog"
optionsWin      "Opcje"
relocation      "Relokacja"
emptyLog        "Plik bdw jest pusty"
getLog          "Historia cigania"
date            "Data"
delayedDown     "Zadania oczekujce"
timeout         "Limit czasu przekroczony"
waiting         "Oczekiwanie"

End

# Labels for frames

Frames

webPage        "Strony WWW"
dir            "Katalog"
levels         "Poziony"
links          "Linki"
filters        "Filtry"
images         "Obrazki"
proxy          "Serwer proxy"
authen         "Autentyfikacja"
time           "Czas"
stop           "Stop"
days           "Dni"

End

# Labels for message Boxes

Messages

formatError     "Nieznany format URL"
notOpen         "Nie moe otworzy: "
noWWW           "Brak URL: "
downloading     "Pobiera"
downSuffix      "Pobiera"
theEnd          "To koniec"
noLinks         "Brak linkw do pobrania"
saveConfig      "Nie mona zachowa kofiguracji"
purged          "Plik czstkowy"
restored        "Plik odzyskany"
notFound        "Nie mona znale: "
unknown         "Katalog nie istnieje\n      Stworzy?"
paused          "Proces zatrzymany"
stopDownload    "Czy chcesz zatrzyma ciaganie?"
resumeSite      "Czy chcesz wznowi pniej?"
noResume        "Brak danych do wznowienia"
noDate          "Serwer nie moe znowi  'Last-Modified' header\n      Continue?"
intNaN          "Wewntrzny link limit\n   nie jest numerem."
extNaN          "Zewntrzny link limit\n   nie jest numerem."
follow          "Przej dalej?"
noLinksOpt      "Nie ma liknkw w aktualnym ustawieniu"
emptyLog        "Plik bdw jest pusty"
noUser          "Nie zosta wprowadzony uytkownik"
noPass          "Nie zostao wprowadzone haso"
proxyAuthFail   "Autentyfikacja proxy nie powioda si"
wrongStart      "Niemoliwy czas startu"
wrongEnd        "Niemozliwy czas zakoczenia"
whichDays       "Wybierz dzie"
timeoutCont     "Serwer nie odpowiada prawidowo\n\tKontynuowa?"
# NOT TRANSLATED
clearLog        "Do you want to clear the log?"

End

# Various labels in dialog windows

Dialogs

file            "Plik"
url             "URL"
left            "Pozostao"
html 	        "Html"
images          "Obrazki"
archives        "Archiwa"
all             "Wszystko"
previous        "Poprzedni"
following       "Nastpny"
activate        "Activate"
deactivate      "Deactivate"
errorLink  	    "Bd w linku:"
errorFile       "Bd w pliku:"
errorCode       "Kod:"
errorMess       "Wiadomo:"
errorCurl       "Bd cURL:"
linkImage       "Link do obrazka"
image           "Obrazek"
fileIncom       "Plik nie skoczony"
noContent       "Pusty link"
dir             "Katalog"
current         "Aktualny"
referer         "Strona odsyajca dalej"
sameProxy       "Uyj taki sam adres proxy"
http            "Http:"
ftp             "Ftp:"
copyLink        "Kopiuj link"
url             "Adres"
localDir        "Lokalny katalog"
ready           "Gotw"
enterUrl        "Wpisz URL"
start           "Wznw"
auto            "Automatycznie"
pause           "Pauza"
stop            "Stop"
options         "Opcje"
# NOT TRANSLATED
fileLog         "File log"
help            "Pomoc"
about           "O programie"
authenUse       "Uyj autentyfikacji"
authenSave      "Zapisz haso"
uplinks         "Po linkach"
levels          "Poziomy"
onlyHtml        "Tylko HTML"
chooseFilter    "Wybierz filtr..."
allImages       "Wszystko"
onlyThumb       "Tylko thumbnails"
noThumb         "Bez thumbnails"
external        "Zewnetrzne linki"
cgi             "CGI"
getMap          "Mapuj"
startNow      "Staruj teraz"
getLog        "Historia"
update        "Uaktualnienie"
queue         "Ustaw w kolejce"
exit          "Wyjcie"
date          "Data"
getMap        "Mapuj"
progDelay     "cigane programy"
begin         "Rozpoczynaj"
end           "Koniec"
noLimit       "Bez limitu czasu"
inme          "Niezwocznie"
afterPage     "Po stronie"
afterFile     "Po pliku"
onlyToday     "Tylko dzi"
on            "Wczony"
monday        "Poniedziaek"
tuesday       "Wtorek"
wednesday     "roda"
thursday      "Czwartek"
friday        "Pitek"
saturday      "Sobota"
sunday        "Niedziela"

timeout       "Limit czasu przekroczony"
relocation    "Relokacja"

# NOT TRANSLATED
code          "Code"
size          "Size"

# This is decimal separator as in PI==3.1415
decimal       "."

End

# Labels for months

Months

01           "Stycze"
02           "Luty"
03           "Marzec"
04           "Kwiecie"
05           "Maj"
06           "Czerwiec"
07           "Lipiec"
08           "Sierpie"
09           "Wrzesie"
10           "Padiernik"
11           "Listopad"
12           "Grudzie"

End

# NOT TRANSLATED
curlCodes

0          "Ok"
1          "Unsupported protocol"
2          "Failed to initialize"
3          "Bad URL"
4          "Bad user info"
5          "Unknown proxy"
6          "Unknown host"
7          "Connection failed"
8          "Weird FTP reply"
9          "FTP access denied"
10         "Wrong password"
11         "Bad server reply"
12         "Bad server reply"
13         "Bad server reply"
14         "Bad server reply"
15         "Wrong FTP host"
16         "Wrong FTP host"
17         "Binary FTP not available"
18         "Incomplete file"
19         "RETR command failed"
22         "Page not found"
23         "Write error"
24         "Bad user name"
25         "FTP STOR error"
26         "Read error"
27         "Out of memory"
28         "Timeout"
29         "ASCII FTP not available"
30         "FTP PORT failed"
31         "FTP REST failed"
32         "FTP SIZE failed"
33         "HTTP range error"
34         "HTTP post error"
35         "SSL connect error"
36         "Bad FTP resume"
37         "Failed to open file"
51         "Bad SSL certificate"
52         "No reply"
404        "Page not found"

End

confWizard
title      "Konfiguracja Getleft'a"
lanTitle   "Wybierz jzyk."
lanSub     "Wybierz domylny jzyk."

proxTitle  "Konfiguracja proxy proxy"
proxSub    "Skonfiguruj proxy, jeli potrzebujesz."

sureTitle  "Sprawd"
sureMssg   "Opucic konfiguracj?"

End
